# coding: utf-8

"""
    Zadara VPSA Object Storage REST API

    # Overview  This document outlines the methods available for administrating your VPSA&#174; Object Storage. The API supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or through the X-Access-Key header. Alternately, you can use the username and password parameters for authentication, but we do not recommend this method for anything other than possibly retrieving an API key.  By default , all operations are allowed only to VPSA Object Storage admin. Some actions are allowed by an account admin and they will be marked on the action's header  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some time to complete. When using the API, this can cause some actions, such as adding drives to storage policy, to be undesirably asynchronous. You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Metering API  Metering information can be retrieved using the VPSA Object Storage API for the following components:  - Accounts - Users - Drives - Virtual Controllers - Load Balancer Groups - Storage Policies  Metering information returned by the API is subject to the following constraints:  - 10 seconds interval - 1 hour range - 1 minute interval - 1 day range - 1 hour interval - 30 days range  Values outside the accepted range will be returned as 0.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Zios.configuration import Configuration


class InlineResponse20052ResponseVcs(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'vc_index': 'int',
        'storage_node': 'str',
        'role': 'str',
        'display_role': 'str',
        'vc_state': 'str',
        'proxy_state': 'str',
        'integrity': 'str',
        'manager_role': 'str',
        'region_id': 'int',
        'zone_id': 'int',
        'policy_type': 'int',
        'allocation_zone': 'str',
        'allocation_zone_display_name': 'str',
        'status': 'str',
        'fe_ip': 'str',
        'fe_ipv6': 'str',
        'be_ip': 'str',
        'lb_group_name': 'str',
        'lb_group_owner': 'str',
        'lb_group_priority': 'int',
        'lb_group_configured': 'str',
        'lb_state': 'str',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'vc_index': 'vc_index',
        'storage_node': 'storage_node',
        'role': 'role',
        'display_role': 'display_role',
        'vc_state': 'vc_state',
        'proxy_state': 'proxy_state',
        'integrity': 'integrity',
        'manager_role': 'manager_role',
        'region_id': 'region_id',
        'zone_id': 'zone_id',
        'policy_type': 'policy_type',
        'allocation_zone': 'allocation-zone',
        'allocation_zone_display_name': 'allocation-zone_display_name',
        'status': 'status',
        'fe_ip': 'fe_ip',
        'fe_ipv6': 'fe_ipv6',
        'be_ip': 'be_ip',
        'lb_group_name': 'lb_group_name',
        'lb_group_owner': 'lb_group_owner',
        'lb_group_priority': 'lb_group_priority',
        'lb_group_configured': 'lb_group_configured',
        'lb_state': 'lb_state',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, vc_index=None, storage_node=None, role=None, display_role=None, vc_state=None, proxy_state=None, integrity=None, manager_role=None, region_id=None, zone_id=None, policy_type=None, allocation_zone=None, allocation_zone_display_name=None, status=None, fe_ip=None, fe_ipv6=None, be_ip=None, lb_group_name=None, lb_group_owner=None, lb_group_priority=None, lb_group_configured=None, lb_state=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20052ResponseVcs - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._vc_index = None
        self._storage_node = None
        self._role = None
        self._display_role = None
        self._vc_state = None
        self._proxy_state = None
        self._integrity = None
        self._manager_role = None
        self._region_id = None
        self._zone_id = None
        self._policy_type = None
        self._allocation_zone = None
        self._allocation_zone_display_name = None
        self._status = None
        self._fe_ip = None
        self._fe_ipv6 = None
        self._be_ip = None
        self._lb_group_name = None
        self._lb_group_owner = None
        self._lb_group_priority = None
        self._lb_group_configured = None
        self._lb_state = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if vc_index is not None:
            self.vc_index = vc_index
        if storage_node is not None:
            self.storage_node = storage_node
        if role is not None:
            self.role = role
        if display_role is not None:
            self.display_role = display_role
        if vc_state is not None:
            self.vc_state = vc_state
        if proxy_state is not None:
            self.proxy_state = proxy_state
        if integrity is not None:
            self.integrity = integrity
        if manager_role is not None:
            self.manager_role = manager_role
        if region_id is not None:
            self.region_id = region_id
        if zone_id is not None:
            self.zone_id = zone_id
        if policy_type is not None:
            self.policy_type = policy_type
        if allocation_zone is not None:
            self.allocation_zone = allocation_zone
        if allocation_zone_display_name is not None:
            self.allocation_zone_display_name = allocation_zone_display_name
        if status is not None:
            self.status = status
        if fe_ip is not None:
            self.fe_ip = fe_ip
        if fe_ipv6 is not None:
            self.fe_ipv6 = fe_ipv6
        if be_ip is not None:
            self.be_ip = be_ip
        if lb_group_name is not None:
            self.lb_group_name = lb_group_name
        if lb_group_owner is not None:
            self.lb_group_owner = lb_group_owner
        if lb_group_priority is not None:
            self.lb_group_priority = lb_group_priority
        if lb_group_configured is not None:
            self.lb_group_configured = lb_group_configured
        if lb_state is not None:
            self.lb_state = lb_state
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The name of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20052ResponseVcs.


        :param name: The name of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def vc_index(self):
        """Gets the vc_index of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The vc_index of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: int
        """
        return self._vc_index

    @vc_index.setter
    def vc_index(self, vc_index):
        """Sets the vc_index of this InlineResponse20052ResponseVcs.


        :param vc_index: The vc_index of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: int
        """

        self._vc_index = vc_index

    @property
    def storage_node(self):
        """Gets the storage_node of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The storage_node of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._storage_node

    @storage_node.setter
    def storage_node(self, storage_node):
        """Sets the storage_node of this InlineResponse20052ResponseVcs.


        :param storage_node: The storage_node of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._storage_node = storage_node

    @property
    def role(self):
        """Gets the role of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The role of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this InlineResponse20052ResponseVcs.


        :param role: The role of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def display_role(self):
        """Gets the display_role of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The display_role of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._display_role

    @display_role.setter
    def display_role(self, display_role):
        """Sets the display_role of this InlineResponse20052ResponseVcs.


        :param display_role: The display_role of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._display_role = display_role

    @property
    def vc_state(self):
        """Gets the vc_state of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The vc_state of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._vc_state

    @vc_state.setter
    def vc_state(self, vc_state):
        """Sets the vc_state of this InlineResponse20052ResponseVcs.


        :param vc_state: The vc_state of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._vc_state = vc_state

    @property
    def proxy_state(self):
        """Gets the proxy_state of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The proxy_state of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._proxy_state

    @proxy_state.setter
    def proxy_state(self, proxy_state):
        """Sets the proxy_state of this InlineResponse20052ResponseVcs.


        :param proxy_state: The proxy_state of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._proxy_state = proxy_state

    @property
    def integrity(self):
        """Gets the integrity of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The integrity of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._integrity

    @integrity.setter
    def integrity(self, integrity):
        """Sets the integrity of this InlineResponse20052ResponseVcs.


        :param integrity: The integrity of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._integrity = integrity

    @property
    def manager_role(self):
        """Gets the manager_role of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The manager_role of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._manager_role

    @manager_role.setter
    def manager_role(self, manager_role):
        """Sets the manager_role of this InlineResponse20052ResponseVcs.


        :param manager_role: The manager_role of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._manager_role = manager_role

    @property
    def region_id(self):
        """Gets the region_id of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The region_id of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: int
        """
        return self._region_id

    @region_id.setter
    def region_id(self, region_id):
        """Sets the region_id of this InlineResponse20052ResponseVcs.


        :param region_id: The region_id of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: int
        """

        self._region_id = region_id

    @property
    def zone_id(self):
        """Gets the zone_id of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The zone_id of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: int
        """
        return self._zone_id

    @zone_id.setter
    def zone_id(self, zone_id):
        """Sets the zone_id of this InlineResponse20052ResponseVcs.


        :param zone_id: The zone_id of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: int
        """

        self._zone_id = zone_id

    @property
    def policy_type(self):
        """Gets the policy_type of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The policy_type of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: int
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """Sets the policy_type of this InlineResponse20052ResponseVcs.


        :param policy_type: The policy_type of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: int
        """

        self._policy_type = policy_type

    @property
    def allocation_zone(self):
        """Gets the allocation_zone of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The allocation_zone of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone

    @allocation_zone.setter
    def allocation_zone(self, allocation_zone):
        """Sets the allocation_zone of this InlineResponse20052ResponseVcs.


        :param allocation_zone: The allocation_zone of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._allocation_zone = allocation_zone

    @property
    def allocation_zone_display_name(self):
        """Gets the allocation_zone_display_name of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The allocation_zone_display_name of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._allocation_zone_display_name

    @allocation_zone_display_name.setter
    def allocation_zone_display_name(self, allocation_zone_display_name):
        """Sets the allocation_zone_display_name of this InlineResponse20052ResponseVcs.


        :param allocation_zone_display_name: The allocation_zone_display_name of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._allocation_zone_display_name = allocation_zone_display_name

    @property
    def status(self):
        """Gets the status of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The status of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20052ResponseVcs.


        :param status: The status of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def fe_ip(self):
        """Gets the fe_ip of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The fe_ip of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._fe_ip

    @fe_ip.setter
    def fe_ip(self, fe_ip):
        """Sets the fe_ip of this InlineResponse20052ResponseVcs.


        :param fe_ip: The fe_ip of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._fe_ip = fe_ip

    @property
    def fe_ipv6(self):
        """Gets the fe_ipv6 of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The fe_ipv6 of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._fe_ipv6

    @fe_ipv6.setter
    def fe_ipv6(self, fe_ipv6):
        """Sets the fe_ipv6 of this InlineResponse20052ResponseVcs.


        :param fe_ipv6: The fe_ipv6 of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._fe_ipv6 = fe_ipv6

    @property
    def be_ip(self):
        """Gets the be_ip of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The be_ip of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._be_ip

    @be_ip.setter
    def be_ip(self, be_ip):
        """Sets the be_ip of this InlineResponse20052ResponseVcs.


        :param be_ip: The be_ip of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._be_ip = be_ip

    @property
    def lb_group_name(self):
        """Gets the lb_group_name of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The lb_group_name of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._lb_group_name

    @lb_group_name.setter
    def lb_group_name(self, lb_group_name):
        """Sets the lb_group_name of this InlineResponse20052ResponseVcs.


        :param lb_group_name: The lb_group_name of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._lb_group_name = lb_group_name

    @property
    def lb_group_owner(self):
        """Gets the lb_group_owner of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The lb_group_owner of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._lb_group_owner

    @lb_group_owner.setter
    def lb_group_owner(self, lb_group_owner):
        """Sets the lb_group_owner of this InlineResponse20052ResponseVcs.


        :param lb_group_owner: The lb_group_owner of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._lb_group_owner = lb_group_owner

    @property
    def lb_group_priority(self):
        """Gets the lb_group_priority of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The lb_group_priority of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: int
        """
        return self._lb_group_priority

    @lb_group_priority.setter
    def lb_group_priority(self, lb_group_priority):
        """Sets the lb_group_priority of this InlineResponse20052ResponseVcs.


        :param lb_group_priority: The lb_group_priority of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: int
        """

        self._lb_group_priority = lb_group_priority

    @property
    def lb_group_configured(self):
        """Gets the lb_group_configured of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The lb_group_configured of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._lb_group_configured

    @lb_group_configured.setter
    def lb_group_configured(self, lb_group_configured):
        """Sets the lb_group_configured of this InlineResponse20052ResponseVcs.


        :param lb_group_configured: The lb_group_configured of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._lb_group_configured = lb_group_configured

    @property
    def lb_state(self):
        """Gets the lb_state of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The lb_state of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._lb_state

    @lb_state.setter
    def lb_state(self, lb_state):
        """Sets the lb_state of this InlineResponse20052ResponseVcs.


        :param lb_state: The lb_state of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._lb_state = lb_state

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The created_at of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20052ResponseVcs.


        :param created_at: The created_at of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20052ResponseVcs.  # noqa: E501


        :return: The modified_at of this InlineResponse20052ResponseVcs.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20052ResponseVcs.


        :param modified_at: The modified_at of this InlineResponse20052ResponseVcs.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20052ResponseVcs, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20052ResponseVcs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20052ResponseVcs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse20084ResponseRaidGroups(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'protection': 'str',
        'mirror_num': 'int',
        'stripe_size': 'int',
        'protection_width': 'int',
        'capacity': 'int',
        'available': 'int',
        'status': 'str',
        'ssd': 'str',
        'mismatch_count': 'int',
        'resync_speed': 'int',
        'min_resync_speed': 'int',
        'max_resync_speed': 'int',
        'created_at': 'str',
        'modified_at': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'protection': 'protection',
        'mirror_num': 'mirror_num',
        'stripe_size': 'stripe_size',
        'protection_width': 'protection_width',
        'capacity': 'capacity',
        'available': 'available',
        'status': 'status',
        'ssd': 'ssd',
        'mismatch_count': 'mismatch_count',
        'resync_speed': 'resync_speed',
        'min_resync_speed': 'min_resync_speed',
        'max_resync_speed': 'max_resync_speed',
        'created_at': 'created_at',
        'modified_at': 'modified_at'
    }

    def __init__(self, name=None, display_name=None, protection=None, mirror_num=None, stripe_size=None, protection_width=None, capacity=None, available=None, status=None, ssd=None, mismatch_count=None, resync_speed=None, min_resync_speed=None, max_resync_speed=None, created_at=None, modified_at=None, _configuration=None):  # noqa: E501
        """InlineResponse20084ResponseRaidGroups - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._protection = None
        self._mirror_num = None
        self._stripe_size = None
        self._protection_width = None
        self._capacity = None
        self._available = None
        self._status = None
        self._ssd = None
        self._mismatch_count = None
        self._resync_speed = None
        self._min_resync_speed = None
        self._max_resync_speed = None
        self._created_at = None
        self._modified_at = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if protection is not None:
            self.protection = protection
        if mirror_num is not None:
            self.mirror_num = mirror_num
        if stripe_size is not None:
            self.stripe_size = stripe_size
        if protection_width is not None:
            self.protection_width = protection_width
        if capacity is not None:
            self.capacity = capacity
        if available is not None:
            self.available = available
        if status is not None:
            self.status = status
        if ssd is not None:
            self.ssd = ssd
        if mismatch_count is not None:
            self.mismatch_count = mismatch_count
        if resync_speed is not None:
            self.resync_speed = resync_speed
        if min_resync_speed is not None:
            self.min_resync_speed = min_resync_speed
        if max_resync_speed is not None:
            self.max_resync_speed = max_resync_speed
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at

    @property
    def name(self):
        """Gets the name of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The name of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20084ResponseRaidGroups.


        :param name: The name of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The display_name of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse20084ResponseRaidGroups.


        :param display_name: The display_name of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def protection(self):
        """Gets the protection of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The protection of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: str
        """
        return self._protection

    @protection.setter
    def protection(self, protection):
        """Sets the protection of this InlineResponse20084ResponseRaidGroups.


        :param protection: The protection of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: str
        """

        self._protection = protection

    @property
    def mirror_num(self):
        """Gets the mirror_num of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The mirror_num of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._mirror_num

    @mirror_num.setter
    def mirror_num(self, mirror_num):
        """Sets the mirror_num of this InlineResponse20084ResponseRaidGroups.


        :param mirror_num: The mirror_num of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._mirror_num = mirror_num

    @property
    def stripe_size(self):
        """Gets the stripe_size of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The stripe_size of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._stripe_size

    @stripe_size.setter
    def stripe_size(self, stripe_size):
        """Sets the stripe_size of this InlineResponse20084ResponseRaidGroups.


        :param stripe_size: The stripe_size of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._stripe_size = stripe_size

    @property
    def protection_width(self):
        """Gets the protection_width of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The protection_width of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._protection_width

    @protection_width.setter
    def protection_width(self, protection_width):
        """Sets the protection_width of this InlineResponse20084ResponseRaidGroups.


        :param protection_width: The protection_width of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._protection_width = protection_width

    @property
    def capacity(self):
        """Gets the capacity of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The capacity of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this InlineResponse20084ResponseRaidGroups.


        :param capacity: The capacity of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._capacity = capacity

    @property
    def available(self):
        """Gets the available of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The available of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._available

    @available.setter
    def available(self, available):
        """Sets the available of this InlineResponse20084ResponseRaidGroups.


        :param available: The available of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._available = available

    @property
    def status(self):
        """Gets the status of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The status of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20084ResponseRaidGroups.


        :param status: The status of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def ssd(self):
        """Gets the ssd of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The ssd of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: str
        """
        return self._ssd

    @ssd.setter
    def ssd(self, ssd):
        """Sets the ssd of this InlineResponse20084ResponseRaidGroups.


        :param ssd: The ssd of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: str
        """

        self._ssd = ssd

    @property
    def mismatch_count(self):
        """Gets the mismatch_count of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The mismatch_count of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._mismatch_count

    @mismatch_count.setter
    def mismatch_count(self, mismatch_count):
        """Sets the mismatch_count of this InlineResponse20084ResponseRaidGroups.


        :param mismatch_count: The mismatch_count of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._mismatch_count = mismatch_count

    @property
    def resync_speed(self):
        """Gets the resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._resync_speed

    @resync_speed.setter
    def resync_speed(self, resync_speed):
        """Sets the resync_speed of this InlineResponse20084ResponseRaidGroups.


        :param resync_speed: The resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._resync_speed = resync_speed

    @property
    def min_resync_speed(self):
        """Gets the min_resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The min_resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._min_resync_speed

    @min_resync_speed.setter
    def min_resync_speed(self, min_resync_speed):
        """Sets the min_resync_speed of this InlineResponse20084ResponseRaidGroups.


        :param min_resync_speed: The min_resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._min_resync_speed = min_resync_speed

    @property
    def max_resync_speed(self):
        """Gets the max_resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The max_resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: int
        """
        return self._max_resync_speed

    @max_resync_speed.setter
    def max_resync_speed(self, max_resync_speed):
        """Sets the max_resync_speed of this InlineResponse20084ResponseRaidGroups.


        :param max_resync_speed: The max_resync_speed of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: int
        """

        self._max_resync_speed = max_resync_speed

    @property
    def created_at(self):
        """Gets the created_at of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The created_at of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InlineResponse20084ResponseRaidGroups.


        :param created_at: The created_at of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this InlineResponse20084ResponseRaidGroups.  # noqa: E501


        :return: The modified_at of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this InlineResponse20084ResponseRaidGroups.


        :param modified_at: The modified_at of this InlineResponse20084ResponseRaidGroups.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20084ResponseRaidGroups, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20084ResponseRaidGroups):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20084ResponseRaidGroups):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from Vpsa.configuration import Configuration


class InlineResponse200136ResponseObsBackupJobSnapshotPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'display_name': 'str',
        'create_policy': 'str',
        'delete_policy': 'str',
        'destination_delete_policy': 'str',
        'paused': 'str',
        'create_empty': 'str',
        'attach': 'str'
    }

    attribute_map = {
        'name': 'name',
        'display_name': 'display_name',
        'create_policy': 'create_policy',
        'delete_policy': 'delete_policy',
        'destination_delete_policy': 'destination_delete_policy',
        'paused': 'paused',
        'create_empty': 'create_empty',
        'attach': 'attach'
    }

    def __init__(self, name=None, display_name=None, create_policy=None, delete_policy=None, destination_delete_policy=None, paused=None, create_empty=None, attach=None, _configuration=None):  # noqa: E501
        """InlineResponse200136ResponseObsBackupJobSnapshotPolicy - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._display_name = None
        self._create_policy = None
        self._delete_policy = None
        self._destination_delete_policy = None
        self._paused = None
        self._create_empty = None
        self._attach = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if display_name is not None:
            self.display_name = display_name
        if create_policy is not None:
            self.create_policy = create_policy
        if delete_policy is not None:
            self.delete_policy = delete_policy
        if destination_delete_policy is not None:
            self.destination_delete_policy = destination_delete_policy
        if paused is not None:
            self.paused = paused
        if create_empty is not None:
            self.create_empty = create_empty
        if attach is not None:
            self.attach = attach

    @property
    def name(self):
        """Gets the name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param name: The name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """
        if (self._configuration.client_side_validation and
                name is not None and not re.search(r'^policy-[0-9a-f]{8}$', name)):  # noqa: E501
            raise ValueError(r"Invalid value for `name`, must be a follow pattern or equal to `/^policy-[0-9a-f]{8}$/`")  # noqa: E501

        self._name = name

    @property
    def display_name(self):
        """Gets the display_name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The display_name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param display_name: The display_name of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def create_policy(self):
        """Gets the create_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The create_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._create_policy

    @create_policy.setter
    def create_policy(self, create_policy):
        """Sets the create_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param create_policy: The create_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """

        self._create_policy = create_policy

    @property
    def delete_policy(self):
        """Gets the delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._delete_policy

    @delete_policy.setter
    def delete_policy(self, delete_policy):
        """Sets the delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param delete_policy: The delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """

        self._delete_policy = delete_policy

    @property
    def destination_delete_policy(self):
        """Gets the destination_delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The destination_delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._destination_delete_policy

    @destination_delete_policy.setter
    def destination_delete_policy(self, destination_delete_policy):
        """Sets the destination_delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param destination_delete_policy: The destination_delete_policy of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """

        self._destination_delete_policy = destination_delete_policy

    @property
    def paused(self):
        """Gets the paused of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The paused of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._paused

    @paused.setter
    def paused(self, paused):
        """Sets the paused of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param paused: The paused of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """

        self._paused = paused

    @property
    def create_empty(self):
        """Gets the create_empty of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The create_empty of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._create_empty

    @create_empty.setter
    def create_empty(self, create_empty):
        """Sets the create_empty of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param create_empty: The create_empty of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """

        self._create_empty = create_empty

    @property
    def attach(self):
        """Gets the attach of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501


        :return: The attach of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :rtype: str
        """
        return self._attach

    @attach.setter
    def attach(self, attach):
        """Sets the attach of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.


        :param attach: The attach of this InlineResponse200136ResponseObsBackupJobSnapshotPolicy.  # noqa: E501
        :type: str
        """

        self._attach = attach

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse200136ResponseObsBackupJobSnapshotPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse200136ResponseObsBackupJobSnapshotPolicy):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse200136ResponseObsBackupJobSnapshotPolicy):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class SetSnmp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'enabled': 'bool',
        'min_severity': 'str',
        'trap_recipient': 'str',
        'proto_version': 'str',
        'community': 'str',
        'security_level': 'str',
        'auth_proto': 'str',
        'auth_user': 'str',
        'auth_password': 'str',
        'privacy_proto': 'str',
        'privacy_password': 'str'
    }

    attribute_map = {
        'enabled': 'enabled',
        'min_severity': 'min_severity',
        'trap_recipient': 'trap_recipient',
        'proto_version': 'proto_version',
        'community': 'community',
        'security_level': 'security_level',
        'auth_proto': 'auth_proto',
        'auth_user': 'auth_user',
        'auth_password': 'auth_password',
        'privacy_proto': 'privacy_proto',
        'privacy_password': 'privacy_password'
    }

    def __init__(self, enabled=None, min_severity=None, trap_recipient=None, proto_version=None, community=None, security_level=None, auth_proto=None, auth_user=None, auth_password=None, privacy_proto=None, privacy_password=None, _configuration=None):  # noqa: E501
        """SetSnmp - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._enabled = None
        self._min_severity = None
        self._trap_recipient = None
        self._proto_version = None
        self._community = None
        self._security_level = None
        self._auth_proto = None
        self._auth_user = None
        self._auth_password = None
        self._privacy_proto = None
        self._privacy_password = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if min_severity is not None:
            self.min_severity = min_severity
        self.trap_recipient = trap_recipient
        self.proto_version = proto_version
        self.community = community
        self.security_level = security_level
        if auth_proto is not None:
            self.auth_proto = auth_proto
        if auth_user is not None:
            self.auth_user = auth_user
        if auth_password is not None:
            self.auth_password = auth_password
        if privacy_proto is not None:
            self.privacy_proto = privacy_proto
        if privacy_password is not None:
            self.privacy_password = privacy_password

    @property
    def enabled(self):
        """Gets the enabled of this SetSnmp.  # noqa: E501


        :return: The enabled of this SetSnmp.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this SetSnmp.


        :param enabled: The enabled of this SetSnmp.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def min_severity(self):
        """Gets the min_severity of this SetSnmp.  # noqa: E501


        :return: The min_severity of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._min_severity

    @min_severity.setter
    def min_severity(self, min_severity):
        """Sets the min_severity of this SetSnmp.


        :param min_severity: The min_severity of this SetSnmp.  # noqa: E501
        :type: str
        """
        allowed_values = ["low", "normal", "high", "urgent"]  # noqa: E501
        if (self._configuration.client_side_validation and
                min_severity not in allowed_values):
            raise ValueError(
                "Invalid value for `min_severity` ({0}), must be one of {1}"  # noqa: E501
                .format(min_severity, allowed_values)
            )

        self._min_severity = min_severity

    @property
    def trap_recipient(self):
        """Gets the trap_recipient of this SetSnmp.  # noqa: E501


        :return: The trap_recipient of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._trap_recipient

    @trap_recipient.setter
    def trap_recipient(self, trap_recipient):
        """Sets the trap_recipient of this SetSnmp.


        :param trap_recipient: The trap_recipient of this SetSnmp.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and trap_recipient is None:
            raise ValueError("Invalid value for `trap_recipient`, must not be `None`")  # noqa: E501

        self._trap_recipient = trap_recipient

    @property
    def proto_version(self):
        """Gets the proto_version of this SetSnmp.  # noqa: E501


        :return: The proto_version of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._proto_version

    @proto_version.setter
    def proto_version(self, proto_version):
        """Sets the proto_version of this SetSnmp.


        :param proto_version: The proto_version of this SetSnmp.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and proto_version is None:
            raise ValueError("Invalid value for `proto_version`, must not be `None`")  # noqa: E501

        self._proto_version = proto_version

    @property
    def community(self):
        """Gets the community of this SetSnmp.  # noqa: E501


        :return: The community of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._community

    @community.setter
    def community(self, community):
        """Sets the community of this SetSnmp.


        :param community: The community of this SetSnmp.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and community is None:
            raise ValueError("Invalid value for `community`, must not be `None`")  # noqa: E501

        self._community = community

    @property
    def security_level(self):
        """Gets the security_level of this SetSnmp.  # noqa: E501


        :return: The security_level of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._security_level

    @security_level.setter
    def security_level(self, security_level):
        """Sets the security_level of this SetSnmp.


        :param security_level: The security_level of this SetSnmp.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and security_level is None:
            raise ValueError("Invalid value for `security_level`, must not be `None`")  # noqa: E501
        allowed_values = ["NoAuthNoPriv", "AuthNoPriv", "AuthPriv"]  # noqa: E501
        if (self._configuration.client_side_validation and
                security_level not in allowed_values):
            raise ValueError(
                "Invalid value for `security_level` ({0}), must be one of {1}"  # noqa: E501
                .format(security_level, allowed_values)
            )

        self._security_level = security_level

    @property
    def auth_proto(self):
        """Gets the auth_proto of this SetSnmp.  # noqa: E501


        :return: The auth_proto of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._auth_proto

    @auth_proto.setter
    def auth_proto(self, auth_proto):
        """Sets the auth_proto of this SetSnmp.


        :param auth_proto: The auth_proto of this SetSnmp.  # noqa: E501
        :type: str
        """
        allowed_values = ["MD5", "SHA-1", "SHA-2-224", "SHA-2-256", "SHA-2-384", "SHA2-2-512"]  # noqa: E501
        if (self._configuration.client_side_validation and
                auth_proto not in allowed_values):
            raise ValueError(
                "Invalid value for `auth_proto` ({0}), must be one of {1}"  # noqa: E501
                .format(auth_proto, allowed_values)
            )

        self._auth_proto = auth_proto

    @property
    def auth_user(self):
        """Gets the auth_user of this SetSnmp.  # noqa: E501


        :return: The auth_user of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._auth_user

    @auth_user.setter
    def auth_user(self, auth_user):
        """Sets the auth_user of this SetSnmp.


        :param auth_user: The auth_user of this SetSnmp.  # noqa: E501
        :type: str
        """

        self._auth_user = auth_user

    @property
    def auth_password(self):
        """Gets the auth_password of this SetSnmp.  # noqa: E501


        :return: The auth_password of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._auth_password

    @auth_password.setter
    def auth_password(self, auth_password):
        """Sets the auth_password of this SetSnmp.


        :param auth_password: The auth_password of this SetSnmp.  # noqa: E501
        :type: str
        """

        self._auth_password = auth_password

    @property
    def privacy_proto(self):
        """Gets the privacy_proto of this SetSnmp.  # noqa: E501


        :return: The privacy_proto of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._privacy_proto

    @privacy_proto.setter
    def privacy_proto(self, privacy_proto):
        """Sets the privacy_proto of this SetSnmp.


        :param privacy_proto: The privacy_proto of this SetSnmp.  # noqa: E501
        :type: str
        """
        allowed_values = ["DES", "AES128", "AES192", "AES256", "3DES"]  # noqa: E501
        if (self._configuration.client_side_validation and
                privacy_proto not in allowed_values):
            raise ValueError(
                "Invalid value for `privacy_proto` ({0}), must be one of {1}"  # noqa: E501
                .format(privacy_proto, allowed_values)
            )

        self._privacy_proto = privacy_proto

    @property
    def privacy_password(self):
        """Gets the privacy_password of this SetSnmp.  # noqa: E501


        :return: The privacy_password of this SetSnmp.  # noqa: E501
        :rtype: str
        """
        return self._privacy_password

    @privacy_password.setter
    def privacy_password(self, privacy_password):
        """Sets the privacy_password of this SetSnmp.


        :param privacy_password: The privacy_password of this SetSnmp.  # noqa: E501
        :type: str
        """

        self._privacy_password = privacy_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SetSnmp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetSnmp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SetSnmp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara VPSA Storage Array REST API

     # Overview  This document outlines the methods available for administrating your Zadara Storage VPSA&#8482;. The Zadara Storage Array REST API   supports form-encoded, JSON, and XML requests, and can return either JSON or XML responses.  ## Usage  The majority of the APIs available require authentication which requires an API token to use. You can retrieve this token through the   Users section of your VPSA, or through the API using the \"Return a user's access key\" API in the Users Section below.  ## Authentication Methods  The authentication token can be passed either through the access_key parameter inside of the body of the REST API request, or   through the X-Access-Key header.  ## Timeouts  By default, all operations that don't complete within five seconds will return a message informing you that the action may take some  time to complete. When using the API, this can cause some actions, such as large volume creation, to be undesirably asynchronous.  You can specify your own timeout with the timeout parameter, in seconds, and a timeout value of -1 specifies an infinite timeout.  ## Specific Fields For Product  Some of the fields/actions used in the API should be used only for a specific product. The following tags are used to mark which   product responds to the fields/actions  VPSA Flash Array  VPSA Storage Array - Hybrid VPSA  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Vpsa.api_client import ApiClient


class FileLifecyclePoliciesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def attach_flc_policy(self, id, attach_flc_policy, **kwargs):  # noqa: E501
        """attach_flc_policy  # noqa: E501

        Attach a volume to a file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_flc_policy(id, attach_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param AttachFlcPolicy attach_flc_policy: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.attach_flc_policy_with_http_info(id, attach_flc_policy, **kwargs)  # noqa: E501
        else:
            (data) = self.attach_flc_policy_with_http_info(id, attach_flc_policy, **kwargs)  # noqa: E501
            return data

    def attach_flc_policy_with_http_info(self, id, attach_flc_policy, **kwargs):  # noqa: E501
        """attach_flc_policy  # noqa: E501

        Attach a volume to a file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_flc_policy_with_http_info(id, attach_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param AttachFlcPolicy attach_flc_policy: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'attach_flc_policy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method attach_flc_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `attach_flc_policy`")  # noqa: E501
        # verify the required parameter 'attach_flc_policy' is set
        if self.api_client.client_side_validation and ('attach_flc_policy' not in params or
                                                       params['attach_flc_policy'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `attach_flc_policy` when calling `attach_flc_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'attach_flc_policy' in params:
            body_params = params['attach_flc_policy']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/{id}/attach.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20039',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_flc_policy(self, create_flc_policy, **kwargs):  # noqa: E501
        """create_flc_policy  # noqa: E501

        Create a new file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_flc_policy(create_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateFlcPolicy create_flc_policy: (required)
        :return: InlineResponse20034
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_flc_policy_with_http_info(create_flc_policy, **kwargs)  # noqa: E501
        else:
            (data) = self.create_flc_policy_with_http_info(create_flc_policy, **kwargs)  # noqa: E501
            return data

    def create_flc_policy_with_http_info(self, create_flc_policy, **kwargs):  # noqa: E501
        """create_flc_policy  # noqa: E501

        Create a new file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_flc_policy_with_http_info(create_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateFlcPolicy create_flc_policy: (required)
        :return: InlineResponse20034
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['create_flc_policy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_flc_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'create_flc_policy' is set
        if self.api_client.client_side_validation and ('create_flc_policy' not in params or
                                                       params['create_flc_policy'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_flc_policy` when calling `create_flc_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_flc_policy' in params:
            body_params = params['create_flc_policy']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies.json', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20034',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_flc_policy(self, id, **kwargs):  # noqa: E501
        """delete_flc_policy  # noqa: E501

        Delete a file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_flc_policy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_flc_policy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_flc_policy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_flc_policy_with_http_info(self, id, **kwargs):  # noqa: E501
        """delete_flc_policy  # noqa: E501

        Delete a file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_flc_policy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20038
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_flc_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_flc_policy`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^lc_policy-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `delete_flc_policy`, must conform to the pattern `/^lc_policy-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/{id}.json', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20038',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def detach_flc_policy(self, id, detach_flc_policy, **kwargs):  # noqa: E501
        """detach_flc_policy  # noqa: E501

        Detach a volume from a file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_flc_policy(id, detach_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param DetachFlcPolicy detach_flc_policy: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.detach_flc_policy_with_http_info(id, detach_flc_policy, **kwargs)  # noqa: E501
        else:
            (data) = self.detach_flc_policy_with_http_info(id, detach_flc_policy, **kwargs)  # noqa: E501
            return data

    def detach_flc_policy_with_http_info(self, id, detach_flc_policy, **kwargs):  # noqa: E501
        """detach_flc_policy  # noqa: E501

        Detach a volume from a file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_flc_policy_with_http_info(id, detach_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param DetachFlcPolicy detach_flc_policy: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'detach_flc_policy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detach_flc_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `detach_flc_policy`")  # noqa: E501
        # verify the required parameter 'detach_flc_policy' is set
        if self.api_client.client_side_validation and ('detach_flc_policy' not in params or
                                                       params['detach_flc_policy'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `detach_flc_policy` when calling `detach_flc_policy`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'detach_flc_policy' in params:
            body_params = params['detach_flc_policy']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/{id}/detach.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20039',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_flc_policies(self, **kwargs):  # noqa: E501
        """get_all_flc_policies  # noqa: E501

        Show file lifecycle policies.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_flc_policies(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetAllFlcPolicies get_all_flc_policies:
        :return: InlineResponse20033
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_flc_policies_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_all_flc_policies_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_all_flc_policies_with_http_info(self, **kwargs):  # noqa: E501
        """get_all_flc_policies  # noqa: E501

        Show file lifecycle policies.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_flc_policies_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetAllFlcPolicies get_all_flc_policies:
        :return: InlineResponse20033
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['get_all_flc_policies']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_flc_policies" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_all_flc_policies' in params:
            body_params = params['get_all_flc_policies']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20033',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_all_flc_policies_rules(self, get_all_flc_policies_rules, **kwargs):  # noqa: E501
        """get_all_flc_policies_rules  # noqa: E501

        Show the rules attaching file lifecycle policies to volumes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_flc_policies_rules(get_all_flc_policies_rules, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetAllFlcPoliciesRules get_all_flc_policies_rules: (required)
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_all_flc_policies_rules_with_http_info(get_all_flc_policies_rules, **kwargs)  # noqa: E501
        else:
            (data) = self.get_all_flc_policies_rules_with_http_info(get_all_flc_policies_rules, **kwargs)  # noqa: E501
            return data

    def get_all_flc_policies_rules_with_http_info(self, get_all_flc_policies_rules, **kwargs):  # noqa: E501
        """get_all_flc_policies_rules  # noqa: E501

        Show the rules attaching file lifecycle policies to volumes.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_all_flc_policies_rules_with_http_info(get_all_flc_policies_rules, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param GetAllFlcPoliciesRules get_all_flc_policies_rules: (required)
        :return: InlineResponse20035
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['get_all_flc_policies_rules']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_all_flc_policies_rules" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'get_all_flc_policies_rules' is set
        if self.api_client.client_side_validation and ('get_all_flc_policies_rules' not in params or
                                                       params['get_all_flc_policies_rules'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `get_all_flc_policies_rules` when calling `get_all_flc_policies_rules`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'get_all_flc_policies_rules' in params:
            body_params = params['get_all_flc_policies_rules']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/rules.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20035',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_flc_policy(self, id, **kwargs):  # noqa: E501
        """get_flc_policy  # noqa: E501

        Retreive a specific file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_flc_policy(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_flc_policy_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_flc_policy_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_flc_policy_with_http_info(self, id, **kwargs):  # noqa: E501
        """get_flc_policy  # noqa: E501

        Retreive a specific file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_flc_policy_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: InlineResponse20036
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_flc_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_flc_policy`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^lc_policy-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `get_flc_policy`, must conform to the pattern `/^lc_policy-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/{id}.json', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20036',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def pause_flc_policy_on_volume(self, id, pause_flc_policy_on_volume, **kwargs):  # noqa: E501
        """pause_flc_policy_on_volume  # noqa: E501

        Pause a file lifecycle policy for a given volume.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_flc_policy_on_volume(id, pause_flc_policy_on_volume, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param PauseFlcPolicyOnVolume pause_flc_policy_on_volume: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.pause_flc_policy_on_volume_with_http_info(id, pause_flc_policy_on_volume, **kwargs)  # noqa: E501
        else:
            (data) = self.pause_flc_policy_on_volume_with_http_info(id, pause_flc_policy_on_volume, **kwargs)  # noqa: E501
            return data

    def pause_flc_policy_on_volume_with_http_info(self, id, pause_flc_policy_on_volume, **kwargs):  # noqa: E501
        """pause_flc_policy_on_volume  # noqa: E501

        Pause a file lifecycle policy for a given volume.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.pause_flc_policy_on_volume_with_http_info(id, pause_flc_policy_on_volume, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param PauseFlcPolicyOnVolume pause_flc_policy_on_volume: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'pause_flc_policy_on_volume']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method pause_flc_policy_on_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `pause_flc_policy_on_volume`")  # noqa: E501
        # verify the required parameter 'pause_flc_policy_on_volume' is set
        if self.api_client.client_side_validation and ('pause_flc_policy_on_volume' not in params or
                                                       params['pause_flc_policy_on_volume'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `pause_flc_policy_on_volume` when calling `pause_flc_policy_on_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'pause_flc_policy_on_volume' in params:
            body_params = params['pause_flc_policy_on_volume']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/{id}/pause.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20037',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def resume_flc_policy_on_volume(self, id, resume_flc_policy_on_volume, **kwargs):  # noqa: E501
        """resume_flc_policy_on_volume  # noqa: E501

        Resume a file lifecycle policy for a given volume.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_flc_policy_on_volume(id, resume_flc_policy_on_volume, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ResumeFlcPolicyOnVolume resume_flc_policy_on_volume: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.resume_flc_policy_on_volume_with_http_info(id, resume_flc_policy_on_volume, **kwargs)  # noqa: E501
        else:
            (data) = self.resume_flc_policy_on_volume_with_http_info(id, resume_flc_policy_on_volume, **kwargs)  # noqa: E501
            return data

    def resume_flc_policy_on_volume_with_http_info(self, id, resume_flc_policy_on_volume, **kwargs):  # noqa: E501
        """resume_flc_policy_on_volume  # noqa: E501

        Resume a file lifecycle policy for a given volume.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.resume_flc_policy_on_volume_with_http_info(id, resume_flc_policy_on_volume, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param ResumeFlcPolicyOnVolume resume_flc_policy_on_volume: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'resume_flc_policy_on_volume']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method resume_flc_policy_on_volume" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `resume_flc_policy_on_volume`")  # noqa: E501
        # verify the required parameter 'resume_flc_policy_on_volume' is set
        if self.api_client.client_side_validation and ('resume_flc_policy_on_volume' not in params or
                                                       params['resume_flc_policy_on_volume'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `resume_flc_policy_on_volume` when calling `resume_flc_policy_on_volume`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'resume_flc_policy_on_volume' in params:
            body_params = params['resume_flc_policy_on_volume']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/{id}/resume.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20037',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_flc_policy(self, id, update_flc_policy, **kwargs):  # noqa: E501
        """update_flc_policy  # noqa: E501

        Updates an existing file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_flc_policy(id, update_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateFlcPolicy update_flc_policy: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_flc_policy_with_http_info(id, update_flc_policy, **kwargs)  # noqa: E501
        else:
            (data) = self.update_flc_policy_with_http_info(id, update_flc_policy, **kwargs)  # noqa: E501
            return data

    def update_flc_policy_with_http_info(self, id, update_flc_policy, **kwargs):  # noqa: E501
        """update_flc_policy  # noqa: E501

        Updates an existing file lifecycle policy.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_flc_policy_with_http_info(id, update_flc_policy, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param UpdateFlcPolicy update_flc_policy: (required)
        :return: InlineResponse20037
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'update_flc_policy']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_flc_policy" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `update_flc_policy`")  # noqa: E501
        # verify the required parameter 'update_flc_policy' is set
        if self.api_client.client_side_validation and ('update_flc_policy' not in params or
                                                       params['update_flc_policy'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_flc_policy` when calling `update_flc_policy`")  # noqa: E501

        if self.api_client.client_side_validation and ('id' in params and not re.search(r'^lc_policy-[0-9a-f]{8}$', params['id'])):  # noqa: E501
            raise ValueError("Invalid value for parameter `id` when calling `update_flc_policy`, must conform to the pattern `/^lc_policy-[0-9a-f]{8}$/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_flc_policy' in params:
            body_params = params['update_flc_policy']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/{id}.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20037',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_flc_policy_scheduling(self, update_flc_policy_scheduling, **kwargs):  # noqa: E501
        """update_flc_policy_scheduling  # noqa: E501

        Updates lifecycle policies run time scheduling.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_flc_policy_scheduling(update_flc_policy_scheduling, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateFlcPolicyScheduling update_flc_policy_scheduling: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_flc_policy_scheduling_with_http_info(update_flc_policy_scheduling, **kwargs)  # noqa: E501
        else:
            (data) = self.update_flc_policy_scheduling_with_http_info(update_flc_policy_scheduling, **kwargs)  # noqa: E501
            return data

    def update_flc_policy_scheduling_with_http_info(self, update_flc_policy_scheduling, **kwargs):  # noqa: E501
        """update_flc_policy_scheduling  # noqa: E501

        Updates lifecycle policies run time scheduling.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_flc_policy_scheduling_with_http_info(update_flc_policy_scheduling, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateFlcPolicyScheduling update_flc_policy_scheduling: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['update_flc_policy_scheduling']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_flc_policy_scheduling" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'update_flc_policy_scheduling' is set
        if self.api_client.client_side_validation and ('update_flc_policy_scheduling' not in params or
                                                       params['update_flc_policy_scheduling'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_flc_policy_scheduling` when calling `update_flc_policy_scheduling`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_flc_policy_scheduling' in params:
            body_params = params['update_flc_policy_scheduling']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/scheduling.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20039',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_flc_recycle_bin(self, update_flc_recycle_bin, **kwargs):  # noqa: E501
        """update_flc_recycle_bin  # noqa: E501

        Configures the recycle bin.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_flc_recycle_bin(update_flc_recycle_bin, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateFlcRecycleBin update_flc_recycle_bin: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_flc_recycle_bin_with_http_info(update_flc_recycle_bin, **kwargs)  # noqa: E501
        else:
            (data) = self.update_flc_recycle_bin_with_http_info(update_flc_recycle_bin, **kwargs)  # noqa: E501
            return data

    def update_flc_recycle_bin_with_http_info(self, update_flc_recycle_bin, **kwargs):  # noqa: E501
        """update_flc_recycle_bin  # noqa: E501

        Configures the recycle bin.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_flc_recycle_bin_with_http_info(update_flc_recycle_bin, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateFlcRecycleBin update_flc_recycle_bin: (required)
        :return: InlineResponse20039
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['update_flc_recycle_bin']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_flc_recycle_bin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'update_flc_recycle_bin' is set
        if self.api_client.client_side_validation and ('update_flc_recycle_bin' not in params or
                                                       params['update_flc_recycle_bin'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `update_flc_recycle_bin` when calling `update_flc_recycle_bin`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_flc_recycle_bin' in params:
            body_params = params['update_flc_recycle_bin']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/flc_policies/recycle_bin.json', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse20039',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class InlineResponse20084User(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'email': 'str',
        'firstname': 'str',
        'lastname': 'str',
        'roles': 'list[InlineResponse20084UserRoles]',
        'admin': 'bool',
        'password': 'str',
        'authentication_token': 'str'
    }

    attribute_map = {
        'id': 'id',
        'email': 'email',
        'firstname': 'firstname',
        'lastname': 'lastname',
        'roles': 'roles',
        'admin': 'admin',
        'password': 'password',
        'authentication_token': 'authentication_token'
    }

    def __init__(self, id=None, email=None, firstname=None, lastname=None, roles=None, admin=None, password=None, authentication_token=None, _configuration=None):  # noqa: E501
        """InlineResponse20084User - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._email = None
        self._firstname = None
        self._lastname = None
        self._roles = None
        self._admin = None
        self._password = None
        self._authentication_token = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if email is not None:
            self.email = email
        if firstname is not None:
            self.firstname = firstname
        if lastname is not None:
            self.lastname = lastname
        if roles is not None:
            self.roles = roles
        if admin is not None:
            self.admin = admin
        if password is not None:
            self.password = password
        if authentication_token is not None:
            self.authentication_token = authentication_token

    @property
    def id(self):
        """Gets the id of this InlineResponse20084User.  # noqa: E501


        :return: The id of this InlineResponse20084User.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20084User.


        :param id: The id of this InlineResponse20084User.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def email(self):
        """Gets the email of this InlineResponse20084User.  # noqa: E501


        :return: The email of this InlineResponse20084User.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this InlineResponse20084User.


        :param email: The email of this InlineResponse20084User.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def firstname(self):
        """Gets the firstname of this InlineResponse20084User.  # noqa: E501


        :return: The firstname of this InlineResponse20084User.  # noqa: E501
        :rtype: str
        """
        return self._firstname

    @firstname.setter
    def firstname(self, firstname):
        """Sets the firstname of this InlineResponse20084User.


        :param firstname: The firstname of this InlineResponse20084User.  # noqa: E501
        :type: str
        """

        self._firstname = firstname

    @property
    def lastname(self):
        """Gets the lastname of this InlineResponse20084User.  # noqa: E501


        :return: The lastname of this InlineResponse20084User.  # noqa: E501
        :rtype: str
        """
        return self._lastname

    @lastname.setter
    def lastname(self, lastname):
        """Sets the lastname of this InlineResponse20084User.


        :param lastname: The lastname of this InlineResponse20084User.  # noqa: E501
        :type: str
        """

        self._lastname = lastname

    @property
    def roles(self):
        """Gets the roles of this InlineResponse20084User.  # noqa: E501


        :return: The roles of this InlineResponse20084User.  # noqa: E501
        :rtype: list[InlineResponse20084UserRoles]
        """
        return self._roles

    @roles.setter
    def roles(self, roles):
        """Sets the roles of this InlineResponse20084User.


        :param roles: The roles of this InlineResponse20084User.  # noqa: E501
        :type: list[InlineResponse20084UserRoles]
        """

        self._roles = roles

    @property
    def admin(self):
        """Gets the admin of this InlineResponse20084User.  # noqa: E501


        :return: The admin of this InlineResponse20084User.  # noqa: E501
        :rtype: bool
        """
        return self._admin

    @admin.setter
    def admin(self, admin):
        """Sets the admin of this InlineResponse20084User.


        :param admin: The admin of this InlineResponse20084User.  # noqa: E501
        :type: bool
        """

        self._admin = admin

    @property
    def password(self):
        """Gets the password of this InlineResponse20084User.  # noqa: E501


        :return: The password of this InlineResponse20084User.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this InlineResponse20084User.


        :param password: The password of this InlineResponse20084User.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def authentication_token(self):
        """Gets the authentication_token of this InlineResponse20084User.  # noqa: E501


        :return: The authentication_token of this InlineResponse20084User.  # noqa: E501
        :rtype: str
        """
        return self._authentication_token

    @authentication_token.setter
    def authentication_token(self, authentication_token):
        """Sets the authentication_token of this InlineResponse20084User.


        :param authentication_token: The authentication_token of this InlineResponse20084User.  # noqa: E501
        :type: str
        """

        self._authentication_token = authentication_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20084User, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20084User):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20084User):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20026DataCache(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total_partitions': 'int',
        'total_gb': 'int',
        'gb_from_engine': 'int',
        'partitions_from_engine': 'int'
    }

    attribute_map = {
        'total_partitions': 'total_partitions',
        'total_gb': 'total_gb',
        'gb_from_engine': 'gb_from_engine',
        'partitions_from_engine': 'partitions_from_engine'
    }

    def __init__(self, total_partitions=None, total_gb=None, gb_from_engine=None, partitions_from_engine=None, _configuration=None):  # noqa: E501
        """InlineResponse20026DataCache - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._total_partitions = None
        self._total_gb = None
        self._gb_from_engine = None
        self._partitions_from_engine = None
        self.discriminator = None

        if total_partitions is not None:
            self.total_partitions = total_partitions
        if total_gb is not None:
            self.total_gb = total_gb
        if gb_from_engine is not None:
            self.gb_from_engine = gb_from_engine
        if partitions_from_engine is not None:
            self.partitions_from_engine = partitions_from_engine

    @property
    def total_partitions(self):
        """Gets the total_partitions of this InlineResponse20026DataCache.  # noqa: E501


        :return: The total_partitions of this InlineResponse20026DataCache.  # noqa: E501
        :rtype: int
        """
        return self._total_partitions

    @total_partitions.setter
    def total_partitions(self, total_partitions):
        """Sets the total_partitions of this InlineResponse20026DataCache.


        :param total_partitions: The total_partitions of this InlineResponse20026DataCache.  # noqa: E501
        :type: int
        """

        self._total_partitions = total_partitions

    @property
    def total_gb(self):
        """Gets the total_gb of this InlineResponse20026DataCache.  # noqa: E501


        :return: The total_gb of this InlineResponse20026DataCache.  # noqa: E501
        :rtype: int
        """
        return self._total_gb

    @total_gb.setter
    def total_gb(self, total_gb):
        """Sets the total_gb of this InlineResponse20026DataCache.


        :param total_gb: The total_gb of this InlineResponse20026DataCache.  # noqa: E501
        :type: int
        """

        self._total_gb = total_gb

    @property
    def gb_from_engine(self):
        """Gets the gb_from_engine of this InlineResponse20026DataCache.  # noqa: E501


        :return: The gb_from_engine of this InlineResponse20026DataCache.  # noqa: E501
        :rtype: int
        """
        return self._gb_from_engine

    @gb_from_engine.setter
    def gb_from_engine(self, gb_from_engine):
        """Sets the gb_from_engine of this InlineResponse20026DataCache.


        :param gb_from_engine: The gb_from_engine of this InlineResponse20026DataCache.  # noqa: E501
        :type: int
        """

        self._gb_from_engine = gb_from_engine

    @property
    def partitions_from_engine(self):
        """Gets the partitions_from_engine of this InlineResponse20026DataCache.  # noqa: E501


        :return: The partitions_from_engine of this InlineResponse20026DataCache.  # noqa: E501
        :rtype: int
        """
        return self._partitions_from_engine

    @partitions_from_engine.setter
    def partitions_from_engine(self, partitions_from_engine):
        """Sets the partitions_from_engine of this InlineResponse20026DataCache.


        :param partitions_from_engine: The partitions_from_engine of this InlineResponse20026DataCache.  # noqa: E501
        :type: int
        """

        self._partitions_from_engine = partitions_from_engine

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20026DataCache, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20026DataCache):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20026DataCache):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Command Center operations

    Command Center operations  # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from CommandCenter.configuration import Configuration


class UpdateEndpointsConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'endpoints_config': 'list[CloudscloudNamesettingsendpointsConfigJsonEndpointsConfig]'
    }

    attribute_map = {
        'type': 'type',
        'endpoints_config': 'endpoints_config'
    }

    def __init__(self, type=None, endpoints_config=None, _configuration=None):  # noqa: E501
        """UpdateEndpointsConfig - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._type = None
        self._endpoints_config = None
        self.discriminator = None

        self.type = type
        self.endpoints_config = endpoints_config

    @property
    def type(self):
        """Gets the type of this UpdateEndpointsConfig.  # noqa: E501

        Upload type  # noqa: E501

        :return: The type of this UpdateEndpointsConfig.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UpdateEndpointsConfig.

        Upload type  # noqa: E501

        :param type: The type of this UpdateEndpointsConfig.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["zsnap", "mag", "zreport", "config"]  # noqa: E501
        if (self._configuration.client_side_validation and
                type not in allowed_values):
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def endpoints_config(self):
        """Gets the endpoints_config of this UpdateEndpointsConfig.  # noqa: E501

        Endpoints configurations to be added to the existing endpoints configurations for the upload type. Each configuration must specify endpoint name. S3 endpoints configurations must also specify bucket name. Up to 1 endpoint for zsnap type, and up to 2 endpoints for all other types.  # noqa: E501

        :return: The endpoints_config of this UpdateEndpointsConfig.  # noqa: E501
        :rtype: list[CloudscloudNamesettingsendpointsConfigJsonEndpointsConfig]
        """
        return self._endpoints_config

    @endpoints_config.setter
    def endpoints_config(self, endpoints_config):
        """Sets the endpoints_config of this UpdateEndpointsConfig.

        Endpoints configurations to be added to the existing endpoints configurations for the upload type. Each configuration must specify endpoint name. S3 endpoints configurations must also specify bucket name. Up to 1 endpoint for zsnap type, and up to 2 endpoints for all other types.  # noqa: E501

        :param endpoints_config: The endpoints_config of this UpdateEndpointsConfig.  # noqa: E501
        :type: list[CloudscloudNamesettingsendpointsConfigJsonEndpointsConfig]
        """
        if self._configuration.client_side_validation and endpoints_config is None:
            raise ValueError("Invalid value for `endpoints_config`, must not be `None`")  # noqa: E501

        self._endpoints_config = endpoints_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateEndpointsConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateEndpointsConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateEndpointsConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Zadara Provisioning Portal API

     # Overview  This document outlines the methods available for creation and high-level administration of Zadara Storage VPSAs via a Zadara Storage Provisioning Portal. This API supports form-encoded requests, and can return either JSON or XML responses.  ## Endpoint  The base URL for the requests is the Provisioning Portal URL you created your VPSA through - for example: https://manage.zadarastorage.com/, and all APIs will be prefixed with /api as noted in the documentation below.  ## Authentication  To use this API, an authentication token is required. The API for retrieving this token can be found below in the Authentication section. You may pass this token in requests either via the the X-Token header or via basic authentication (base64 encoded) in Authorization header.  ## Questions  If you have any questions or need support involving the REST API, please contact for assistance.   # noqa: E501

    OpenAPI spec version: 23.03-sp1
    Contact: support@zadarastorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from ProvisioningPortal.configuration import Configuration


class InlineResponse20027Data(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'allocation_zones': 'list[str]',
        'cache': 'InlineResponse20025Cache',
        'app_engine': 'InlineResponse20027DataAppEngine',
        'description': 'str',
        'drive_count': 'int',
        'drives': 'InlineResponse20025Drives',
        'engine': 'InlineResponse20027DataEngine',
        'id': 'int',
        'initial_passcode': 'str',
        'internal_name': 'str',
        'fibre_channel': 'bool',
        'locked_down': 'bool',
        'management_url': 'str',
        'ip_address': 'str',
        'ipv6_address': 'str',
        'name': 'str',
        'nova_id': 'int',
        'provider': 'InlineResponse20027DataProvider',
        'status': 'str',
        'proxy_virtual_controllers': 'int',
        'proxy_storage_virtual_controllers': 'int',
        'storage_policies': 'list[InlineResponse20027DataStoragePolicies]',
        'public_zios': 'InlineResponse20027DataPubliczios',
        'virtual_network_interfaces': 'list[str]',
        'time_created_gmt': 'str',
        'product': 'str',
        'typ': 'str',
        'flc_enabled': 'bool',
        'iscsi_dual_target_mode_enabled': 'bool'
    }

    attribute_map = {
        'allocation_zones': 'allocation-zones',
        'cache': 'cache',
        'app_engine': 'app_engine',
        'description': 'description',
        'drive_count': 'drive_count',
        'drives': 'drives',
        'engine': 'engine',
        'id': 'id',
        'initial_passcode': 'initial_passcode',
        'internal_name': 'internal_name',
        'fibre_channel': 'fibre_channel',
        'locked_down': 'locked_down',
        'management_url': 'management_url',
        'ip_address': 'ip_address',
        'ipv6_address': 'ipv6_address',
        'name': 'name',
        'nova_id': 'nova_id',
        'provider': 'provider',
        'status': 'status',
        'proxy_virtual_controllers': 'proxy_virtual_controllers',
        'proxy_storage_virtual_controllers': 'proxy_storage_virtual_controllers',
        'storage_policies': 'storage_policies',
        'public_zios': 'public-zios',
        'virtual_network_interfaces': 'virtual_network_interfaces',
        'time_created_gmt': 'time_created_gmt',
        'product': 'product',
        'typ': 'typ',
        'flc_enabled': 'flc_enabled',
        'iscsi_dual_target_mode_enabled': 'iscsi_dual_target_mode_enabled'
    }

    def __init__(self, allocation_zones=None, cache=None, app_engine=None, description=None, drive_count=None, drives=None, engine=None, id=None, initial_passcode=None, internal_name=None, fibre_channel=None, locked_down=None, management_url=None, ip_address=None, ipv6_address=None, name=None, nova_id=None, provider=None, status=None, proxy_virtual_controllers=None, proxy_storage_virtual_controllers=None, storage_policies=None, public_zios=None, virtual_network_interfaces=None, time_created_gmt=None, product=None, typ=None, flc_enabled=None, iscsi_dual_target_mode_enabled=None, _configuration=None):  # noqa: E501
        """InlineResponse20027Data - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._allocation_zones = None
        self._cache = None
        self._app_engine = None
        self._description = None
        self._drive_count = None
        self._drives = None
        self._engine = None
        self._id = None
        self._initial_passcode = None
        self._internal_name = None
        self._fibre_channel = None
        self._locked_down = None
        self._management_url = None
        self._ip_address = None
        self._ipv6_address = None
        self._name = None
        self._nova_id = None
        self._provider = None
        self._status = None
        self._proxy_virtual_controllers = None
        self._proxy_storage_virtual_controllers = None
        self._storage_policies = None
        self._public_zios = None
        self._virtual_network_interfaces = None
        self._time_created_gmt = None
        self._product = None
        self._typ = None
        self._flc_enabled = None
        self._iscsi_dual_target_mode_enabled = None
        self.discriminator = None

        if allocation_zones is not None:
            self.allocation_zones = allocation_zones
        if cache is not None:
            self.cache = cache
        if app_engine is not None:
            self.app_engine = app_engine
        if description is not None:
            self.description = description
        if drive_count is not None:
            self.drive_count = drive_count
        if drives is not None:
            self.drives = drives
        if engine is not None:
            self.engine = engine
        if id is not None:
            self.id = id
        if initial_passcode is not None:
            self.initial_passcode = initial_passcode
        if internal_name is not None:
            self.internal_name = internal_name
        if fibre_channel is not None:
            self.fibre_channel = fibre_channel
        if locked_down is not None:
            self.locked_down = locked_down
        if management_url is not None:
            self.management_url = management_url
        if ip_address is not None:
            self.ip_address = ip_address
        if ipv6_address is not None:
            self.ipv6_address = ipv6_address
        if name is not None:
            self.name = name
        if nova_id is not None:
            self.nova_id = nova_id
        if provider is not None:
            self.provider = provider
        if status is not None:
            self.status = status
        if proxy_virtual_controllers is not None:
            self.proxy_virtual_controllers = proxy_virtual_controllers
        if proxy_storage_virtual_controllers is not None:
            self.proxy_storage_virtual_controllers = proxy_storage_virtual_controllers
        if storage_policies is not None:
            self.storage_policies = storage_policies
        if public_zios is not None:
            self.public_zios = public_zios
        if virtual_network_interfaces is not None:
            self.virtual_network_interfaces = virtual_network_interfaces
        if time_created_gmt is not None:
            self.time_created_gmt = time_created_gmt
        if product is not None:
            self.product = product
        if typ is not None:
            self.typ = typ
        if flc_enabled is not None:
            self.flc_enabled = flc_enabled
        if iscsi_dual_target_mode_enabled is not None:
            self.iscsi_dual_target_mode_enabled = iscsi_dual_target_mode_enabled

    @property
    def allocation_zones(self):
        """Gets the allocation_zones of this InlineResponse20027Data.  # noqa: E501


        :return: The allocation_zones of this InlineResponse20027Data.  # noqa: E501
        :rtype: list[str]
        """
        return self._allocation_zones

    @allocation_zones.setter
    def allocation_zones(self, allocation_zones):
        """Sets the allocation_zones of this InlineResponse20027Data.


        :param allocation_zones: The allocation_zones of this InlineResponse20027Data.  # noqa: E501
        :type: list[str]
        """

        self._allocation_zones = allocation_zones

    @property
    def cache(self):
        """Gets the cache of this InlineResponse20027Data.  # noqa: E501


        :return: The cache of this InlineResponse20027Data.  # noqa: E501
        :rtype: InlineResponse20025Cache
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this InlineResponse20027Data.


        :param cache: The cache of this InlineResponse20027Data.  # noqa: E501
        :type: InlineResponse20025Cache
        """

        self._cache = cache

    @property
    def app_engine(self):
        """Gets the app_engine of this InlineResponse20027Data.  # noqa: E501


        :return: The app_engine of this InlineResponse20027Data.  # noqa: E501
        :rtype: InlineResponse20027DataAppEngine
        """
        return self._app_engine

    @app_engine.setter
    def app_engine(self, app_engine):
        """Sets the app_engine of this InlineResponse20027Data.


        :param app_engine: The app_engine of this InlineResponse20027Data.  # noqa: E501
        :type: InlineResponse20027DataAppEngine
        """

        self._app_engine = app_engine

    @property
    def description(self):
        """Gets the description of this InlineResponse20027Data.  # noqa: E501


        :return: The description of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this InlineResponse20027Data.


        :param description: The description of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def drive_count(self):
        """Gets the drive_count of this InlineResponse20027Data.  # noqa: E501


        :return: The drive_count of this InlineResponse20027Data.  # noqa: E501
        :rtype: int
        """
        return self._drive_count

    @drive_count.setter
    def drive_count(self, drive_count):
        """Sets the drive_count of this InlineResponse20027Data.


        :param drive_count: The drive_count of this InlineResponse20027Data.  # noqa: E501
        :type: int
        """

        self._drive_count = drive_count

    @property
    def drives(self):
        """Gets the drives of this InlineResponse20027Data.  # noqa: E501


        :return: The drives of this InlineResponse20027Data.  # noqa: E501
        :rtype: InlineResponse20025Drives
        """
        return self._drives

    @drives.setter
    def drives(self, drives):
        """Sets the drives of this InlineResponse20027Data.


        :param drives: The drives of this InlineResponse20027Data.  # noqa: E501
        :type: InlineResponse20025Drives
        """

        self._drives = drives

    @property
    def engine(self):
        """Gets the engine of this InlineResponse20027Data.  # noqa: E501


        :return: The engine of this InlineResponse20027Data.  # noqa: E501
        :rtype: InlineResponse20027DataEngine
        """
        return self._engine

    @engine.setter
    def engine(self, engine):
        """Sets the engine of this InlineResponse20027Data.


        :param engine: The engine of this InlineResponse20027Data.  # noqa: E501
        :type: InlineResponse20027DataEngine
        """

        self._engine = engine

    @property
    def id(self):
        """Gets the id of this InlineResponse20027Data.  # noqa: E501


        :return: The id of this InlineResponse20027Data.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InlineResponse20027Data.


        :param id: The id of this InlineResponse20027Data.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def initial_passcode(self):
        """Gets the initial_passcode of this InlineResponse20027Data.  # noqa: E501


        :return: The initial_passcode of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._initial_passcode

    @initial_passcode.setter
    def initial_passcode(self, initial_passcode):
        """Sets the initial_passcode of this InlineResponse20027Data.


        :param initial_passcode: The initial_passcode of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._initial_passcode = initial_passcode

    @property
    def internal_name(self):
        """Gets the internal_name of this InlineResponse20027Data.  # noqa: E501


        :return: The internal_name of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._internal_name

    @internal_name.setter
    def internal_name(self, internal_name):
        """Sets the internal_name of this InlineResponse20027Data.


        :param internal_name: The internal_name of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._internal_name = internal_name

    @property
    def fibre_channel(self):
        """Gets the fibre_channel of this InlineResponse20027Data.  # noqa: E501


        :return: The fibre_channel of this InlineResponse20027Data.  # noqa: E501
        :rtype: bool
        """
        return self._fibre_channel

    @fibre_channel.setter
    def fibre_channel(self, fibre_channel):
        """Sets the fibre_channel of this InlineResponse20027Data.


        :param fibre_channel: The fibre_channel of this InlineResponse20027Data.  # noqa: E501
        :type: bool
        """

        self._fibre_channel = fibre_channel

    @property
    def locked_down(self):
        """Gets the locked_down of this InlineResponse20027Data.  # noqa: E501


        :return: The locked_down of this InlineResponse20027Data.  # noqa: E501
        :rtype: bool
        """
        return self._locked_down

    @locked_down.setter
    def locked_down(self, locked_down):
        """Sets the locked_down of this InlineResponse20027Data.


        :param locked_down: The locked_down of this InlineResponse20027Data.  # noqa: E501
        :type: bool
        """

        self._locked_down = locked_down

    @property
    def management_url(self):
        """Gets the management_url of this InlineResponse20027Data.  # noqa: E501


        :return: The management_url of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._management_url

    @management_url.setter
    def management_url(self, management_url):
        """Sets the management_url of this InlineResponse20027Data.


        :param management_url: The management_url of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._management_url = management_url

    @property
    def ip_address(self):
        """Gets the ip_address of this InlineResponse20027Data.  # noqa: E501


        :return: The ip_address of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this InlineResponse20027Data.


        :param ip_address: The ip_address of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._ip_address = ip_address

    @property
    def ipv6_address(self):
        """Gets the ipv6_address of this InlineResponse20027Data.  # noqa: E501


        :return: The ipv6_address of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._ipv6_address

    @ipv6_address.setter
    def ipv6_address(self, ipv6_address):
        """Sets the ipv6_address of this InlineResponse20027Data.


        :param ipv6_address: The ipv6_address of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._ipv6_address = ipv6_address

    @property
    def name(self):
        """Gets the name of this InlineResponse20027Data.  # noqa: E501


        :return: The name of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InlineResponse20027Data.


        :param name: The name of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def nova_id(self):
        """Gets the nova_id of this InlineResponse20027Data.  # noqa: E501


        :return: The nova_id of this InlineResponse20027Data.  # noqa: E501
        :rtype: int
        """
        return self._nova_id

    @nova_id.setter
    def nova_id(self, nova_id):
        """Sets the nova_id of this InlineResponse20027Data.


        :param nova_id: The nova_id of this InlineResponse20027Data.  # noqa: E501
        :type: int
        """

        self._nova_id = nova_id

    @property
    def provider(self):
        """Gets the provider of this InlineResponse20027Data.  # noqa: E501


        :return: The provider of this InlineResponse20027Data.  # noqa: E501
        :rtype: InlineResponse20027DataProvider
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this InlineResponse20027Data.


        :param provider: The provider of this InlineResponse20027Data.  # noqa: E501
        :type: InlineResponse20027DataProvider
        """

        self._provider = provider

    @property
    def status(self):
        """Gets the status of this InlineResponse20027Data.  # noqa: E501


        :return: The status of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this InlineResponse20027Data.


        :param status: The status of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def proxy_virtual_controllers(self):
        """Gets the proxy_virtual_controllers of this InlineResponse20027Data.  # noqa: E501


        :return: The proxy_virtual_controllers of this InlineResponse20027Data.  # noqa: E501
        :rtype: int
        """
        return self._proxy_virtual_controllers

    @proxy_virtual_controllers.setter
    def proxy_virtual_controllers(self, proxy_virtual_controllers):
        """Sets the proxy_virtual_controllers of this InlineResponse20027Data.


        :param proxy_virtual_controllers: The proxy_virtual_controllers of this InlineResponse20027Data.  # noqa: E501
        :type: int
        """

        self._proxy_virtual_controllers = proxy_virtual_controllers

    @property
    def proxy_storage_virtual_controllers(self):
        """Gets the proxy_storage_virtual_controllers of this InlineResponse20027Data.  # noqa: E501


        :return: The proxy_storage_virtual_controllers of this InlineResponse20027Data.  # noqa: E501
        :rtype: int
        """
        return self._proxy_storage_virtual_controllers

    @proxy_storage_virtual_controllers.setter
    def proxy_storage_virtual_controllers(self, proxy_storage_virtual_controllers):
        """Sets the proxy_storage_virtual_controllers of this InlineResponse20027Data.


        :param proxy_storage_virtual_controllers: The proxy_storage_virtual_controllers of this InlineResponse20027Data.  # noqa: E501
        :type: int
        """

        self._proxy_storage_virtual_controllers = proxy_storage_virtual_controllers

    @property
    def storage_policies(self):
        """Gets the storage_policies of this InlineResponse20027Data.  # noqa: E501


        :return: The storage_policies of this InlineResponse20027Data.  # noqa: E501
        :rtype: list[InlineResponse20027DataStoragePolicies]
        """
        return self._storage_policies

    @storage_policies.setter
    def storage_policies(self, storage_policies):
        """Sets the storage_policies of this InlineResponse20027Data.


        :param storage_policies: The storage_policies of this InlineResponse20027Data.  # noqa: E501
        :type: list[InlineResponse20027DataStoragePolicies]
        """

        self._storage_policies = storage_policies

    @property
    def public_zios(self):
        """Gets the public_zios of this InlineResponse20027Data.  # noqa: E501


        :return: The public_zios of this InlineResponse20027Data.  # noqa: E501
        :rtype: InlineResponse20027DataPubliczios
        """
        return self._public_zios

    @public_zios.setter
    def public_zios(self, public_zios):
        """Sets the public_zios of this InlineResponse20027Data.


        :param public_zios: The public_zios of this InlineResponse20027Data.  # noqa: E501
        :type: InlineResponse20027DataPubliczios
        """

        self._public_zios = public_zios

    @property
    def virtual_network_interfaces(self):
        """Gets the virtual_network_interfaces of this InlineResponse20027Data.  # noqa: E501


        :return: The virtual_network_interfaces of this InlineResponse20027Data.  # noqa: E501
        :rtype: list[str]
        """
        return self._virtual_network_interfaces

    @virtual_network_interfaces.setter
    def virtual_network_interfaces(self, virtual_network_interfaces):
        """Sets the virtual_network_interfaces of this InlineResponse20027Data.


        :param virtual_network_interfaces: The virtual_network_interfaces of this InlineResponse20027Data.  # noqa: E501
        :type: list[str]
        """

        self._virtual_network_interfaces = virtual_network_interfaces

    @property
    def time_created_gmt(self):
        """Gets the time_created_gmt of this InlineResponse20027Data.  # noqa: E501


        :return: The time_created_gmt of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._time_created_gmt

    @time_created_gmt.setter
    def time_created_gmt(self, time_created_gmt):
        """Sets the time_created_gmt of this InlineResponse20027Data.


        :param time_created_gmt: The time_created_gmt of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._time_created_gmt = time_created_gmt

    @property
    def product(self):
        """Gets the product of this InlineResponse20027Data.  # noqa: E501


        :return: The product of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this InlineResponse20027Data.


        :param product: The product of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._product = product

    @property
    def typ(self):
        """Gets the typ of this InlineResponse20027Data.  # noqa: E501


        :return: The typ of this InlineResponse20027Data.  # noqa: E501
        :rtype: str
        """
        return self._typ

    @typ.setter
    def typ(self, typ):
        """Sets the typ of this InlineResponse20027Data.


        :param typ: The typ of this InlineResponse20027Data.  # noqa: E501
        :type: str
        """

        self._typ = typ

    @property
    def flc_enabled(self):
        """Gets the flc_enabled of this InlineResponse20027Data.  # noqa: E501


        :return: The flc_enabled of this InlineResponse20027Data.  # noqa: E501
        :rtype: bool
        """
        return self._flc_enabled

    @flc_enabled.setter
    def flc_enabled(self, flc_enabled):
        """Sets the flc_enabled of this InlineResponse20027Data.


        :param flc_enabled: The flc_enabled of this InlineResponse20027Data.  # noqa: E501
        :type: bool
        """

        self._flc_enabled = flc_enabled

    @property
    def iscsi_dual_target_mode_enabled(self):
        """Gets the iscsi_dual_target_mode_enabled of this InlineResponse20027Data.  # noqa: E501


        :return: The iscsi_dual_target_mode_enabled of this InlineResponse20027Data.  # noqa: E501
        :rtype: bool
        """
        return self._iscsi_dual_target_mode_enabled

    @iscsi_dual_target_mode_enabled.setter
    def iscsi_dual_target_mode_enabled(self, iscsi_dual_target_mode_enabled):
        """Sets the iscsi_dual_target_mode_enabled of this InlineResponse20027Data.


        :param iscsi_dual_target_mode_enabled: The iscsi_dual_target_mode_enabled of this InlineResponse20027Data.  # noqa: E501
        :type: bool
        """

        self._iscsi_dual_target_mode_enabled = iscsi_dual_target_mode_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse20027Data, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse20027Data):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InlineResponse20027Data):
            return True

        return self.to_dict() != other.to_dict()
